# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`clamav`](#clamav): Installs the command line ClamAV anti-virus scanner.
* [`clamav::set_schedule`](#clamav--set_schedule): Allows you to set a schedule for ClamAV to run a check on your system via cron

## Classes

### <a name="clamav"></a>`clamav`

If you wish to schedule a virus scan, you will need to create a cron job that
is appropriate, or drop a script into the cron.* directory that is
appropriate.

#### Parameters

The following parameters are available in the `clamav` class:

* [`enable`](#-clamav--enable)
* [`manage_group_and_user`](#-clamav--manage_group_and_user)
* [`clamav_user`](#-clamav--clamav_user)
* [`clamav_group`](#-clamav--clamav_group)
* [`package_name`](#-clamav--package_name)
* [`enable_freshclam`](#-clamav--enable_freshclam)
* [`enable_data_rsync`](#-clamav--enable_data_rsync)
* [`schedule_scan`](#-clamav--schedule_scan)
* [`rsync_source`](#-clamav--rsync_source)
* [`rsync_server`](#-clamav--rsync_server)
* [`rsync_timeout`](#-clamav--rsync_timeout)
* [`package_ensure`](#-clamav--package_ensure)

##### <a name="-clamav--enable"></a>`enable`

Data type: `Boolean`

Disables/Enables clamav

* Toggles freshclam/clamscan cronjobs, selbooleans, rsync, and package
  installation.

Default value: `true`

##### <a name="-clamav--manage_group_and_user"></a>`manage_group_and_user`

Data type: `Boolean`

Optionally manage the clamav user and group.

Default value: `true`

##### <a name="-clamav--clamav_user"></a>`clamav_user`

Data type: `String`

The clamav user.

Default value: `'clam'`

##### <a name="-clamav--clamav_group"></a>`clamav_group`

Data type: `String`

The clamav group.

Default value: `'clam'`

##### <a name="-clamav--package_name"></a>`package_name`

Data type: `String`

The name of clamav rpm package.

Default value: `'clamav'`

##### <a name="-clamav--enable_freshclam"></a>`enable_freshclam`

Data type: `Boolean`

If true, will enable the freshclam cron job.

Default value: `false`

##### <a name="-clamav--enable_data_rsync"></a>`enable_data_rsync`

Data type: `Boolean`

If true, will use the SIMP rsync subsystem to pull down clamav DAT files.

* NOTE: `$enable_freshclam` takes precedence

Default value: `false`

##### <a name="-clamav--schedule_scan"></a>`schedule_scan`

Data type: `Boolean`

If true, will enable the scheduled system scan.

* The default targets are *extremely* conservative so you will probably
  want to adjust this.

Default value: `true`

##### <a name="-clamav--rsync_source"></a>`rsync_source`

Data type: `String`

The rsync server source path for the clamav definitions.

* Setting this parameter to an empty String will disable the clamav rsync.

Default value: `"clamav_${facts['environment']}/"`

##### <a name="-clamav--rsync_server"></a>`rsync_server`

Data type: `Simplib::Host`

The hostname or IP of the rsync server providing clamav definitions.

Default value: `simplib::lookup('simp_options::rsync::server', { 'default_value' => '127.0.0.1' })`

##### <a name="-clamav--rsync_timeout"></a>`rsync_timeout`

Data type: `Integer`

The amount of time, in seconds, to wait for rsync to respond.

Default value: `simplib::lookup('simp_options::rsync::timeout', { 'default_value' => 2 })`

##### <a name="-clamav--package_ensure"></a>`package_ensure`

Data type: `String[1]`

The value used for package ensure attribute.

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

### <a name="clamav--set_schedule"></a>`clamav::set_schedule`

* All 'yes/no' variables have been translated to 'true/false' for consistency.

* Defaults to weekly.

* **See also**
  * clamscan(1)
    * for any undefined variables.

#### Parameters

The following parameters are available in the `clamav::set_schedule` class:

* [`enable`](#-clamav--set_schedule--enable)
* [`minute`](#-clamav--set_schedule--minute)
* [`hour`](#-clamav--set_schedule--hour)
* [`monthday`](#-clamav--set_schedule--monthday)
* [`month`](#-clamav--set_schedule--month)
* [`weekday`](#-clamav--set_schedule--weekday)
* [`nice_level`](#-clamav--set_schedule--nice_level)
* [`scan_targets`](#-clamav--set_schedule--scan_targets)
* [`official_db_only`](#-clamav--set_schedule--official_db_only)
* [`logfile`](#-clamav--set_schedule--logfile)
* [`recursive`](#-clamav--set_schedule--recursive)
* [`cross_fs`](#-clamav--set_schedule--cross_fs)
* [`summary`](#-clamav--set_schedule--summary)
* [`infected_only`](#-clamav--set_schedule--infected_only)
* [`bytecode`](#-clamav--set_schedule--bytecode)
* [`bytecode_unsigned`](#-clamav--set_schedule--bytecode_unsigned)
* [`bytecode_timeout`](#-clamav--set_schedule--bytecode_timeout)
* [`detect_pua`](#-clamav--set_schedule--detect_pua)
* [`exclude_pua`](#-clamav--set_schedule--exclude_pua)
* [`include_pua`](#-clamav--set_schedule--include_pua)
* [`max_files`](#-clamav--set_schedule--max_files)
* [`max_filesize`](#-clamav--set_schedule--max_filesize)
* [`max_scansize`](#-clamav--set_schedule--max_scansize)
* [`max_recursion`](#-clamav--set_schedule--max_recursion)
* [`max_dir_recursion`](#-clamav--set_schedule--max_dir_recursion)
* [`logrotate`](#-clamav--set_schedule--logrotate)

##### <a name="-clamav--set_schedule--enable"></a>`enable`

Data type: `Boolean`

Enables/Disables the clamscan cronjob.  Defaults to true.

Default value: `simplib::lookup('clamav::enable', { 'default_value' => true})`

##### <a name="-clamav--set_schedule--minute"></a>`minute`

Data type: `Simplib::Cron::Minute`



Default value: `'32'`

##### <a name="-clamav--set_schedule--hour"></a>`hour`

Data type: `Simplib::Cron::Hour`



Default value: `'5'`

##### <a name="-clamav--set_schedule--monthday"></a>`monthday`

Data type: `Simplib::Cron::MonthDay`



Default value: `'*'`

##### <a name="-clamav--set_schedule--month"></a>`month`

Data type: `Simplib::Cron::Month`



Default value: `'*'`

##### <a name="-clamav--set_schedule--weekday"></a>`weekday`

Data type: `Simplib::Cron::Weekday`



Default value: `'0'`

##### <a name="-clamav--set_schedule--nice_level"></a>`nice_level`

Data type: `Integer`

The system 'nice' level at which to run the virus scan.

Default value: `19`

##### <a name="-clamav--set_schedule--scan_targets"></a>`scan_targets`

Data type: `Array[Stdlib::Absolutepath]`

An array of directories upon which to perform this scan.

Default value: `['/tmp','/var/tmp','/dev/shm']`

##### <a name="-clamav--set_schedule--official_db_only"></a>`official_db_only`

Data type: `Boolean`



Default value: `true`

##### <a name="-clamav--set_schedule--logfile"></a>`logfile`

Data type: `Stdlib::Absolutepath`



Default value: `'/var/log/clamscan.log'`

##### <a name="-clamav--set_schedule--recursive"></a>`recursive`

Data type: `Boolean`



Default value: `true`

##### <a name="-clamav--set_schedule--cross_fs"></a>`cross_fs`

Data type: `Boolean`



Default value: `true`

##### <a name="-clamav--set_schedule--summary"></a>`summary`

Data type: `Boolean`



Default value: `false`

##### <a name="-clamav--set_schedule--infected_only"></a>`infected_only`

Data type: `Boolean`



Default value: `true`

##### <a name="-clamav--set_schedule--bytecode"></a>`bytecode`

Data type: `Boolean`



Default value: `true`

##### <a name="-clamav--set_schedule--bytecode_unsigned"></a>`bytecode_unsigned`

Data type: `Boolean`



Default value: `false`

##### <a name="-clamav--set_schedule--bytecode_timeout"></a>`bytecode_timeout`

Data type: `Integer`



Default value: `60000`

##### <a name="-clamav--set_schedule--detect_pua"></a>`detect_pua`

Data type: `Boolean`



Default value: `false`

##### <a name="-clamav--set_schedule--exclude_pua"></a>`exclude_pua`

Data type: `Array[String]`



Default value: `[]`

##### <a name="-clamav--set_schedule--include_pua"></a>`include_pua`

Data type: `Array[String]`



Default value: `[]`

##### <a name="-clamav--set_schedule--max_files"></a>`max_files`

Data type: `Integer`



Default value: `10000`

##### <a name="-clamav--set_schedule--max_filesize"></a>`max_filesize`

Data type: `Integer`

The maximum archive size to scan, in megabytes.

Default value: `25`

##### <a name="-clamav--set_schedule--max_scansize"></a>`max_scansize`

Data type: `Integer`

The maximum scanned file size to scan, in megabytes.

Default value: `100`

##### <a name="-clamav--set_schedule--max_recursion"></a>`max_recursion`

Data type: `Integer`



Default value: `16`

##### <a name="-clamav--set_schedule--max_dir_recursion"></a>`max_dir_recursion`

Data type: `Integer`



Default value: `15`

##### <a name="-clamav--set_schedule--logrotate"></a>`logrotate`

Data type: `Boolean`

Enable the use of the SIMP logrotate capabilities.

Default value: `simplib::lookup('simp_options::logrotate', { 'default_value' => false })`

